# CSPP Geo Gridded GLM v1.1

January 2025

**Copyright (C) 2020-2025 Space Science and Engineering Center (SSEC), University 
of Wisconsin-Madison.**

University of Wisconsin-Madison
Space Science and Engineering Center
1225 West Dayton Street
Madison, WI  53706

CSPP Geo Software Lead: Levi Pfantz
CSPP Geo Product Manager: Scott Lindstrom

Contact: csppgeo.issues@ssec.wisc.edu
Gridded GLM Documentation: https://cimss.ssec.wisc.edu/csppgeo/gridded-glm.html
CSPP Geo Home Page: http://cimss.ssec.wisc.edu/csppgeo/


## OVERVIEW

CSPP Geo Gridded GLM software processes GOES-16, -17, -18 and -19 Geostationary Lightning Mapper (GLM) Level 2+ LCFA products in mission standard format, generating a new set of products which have been gridded to the Advanced Baseline Imager (ABI) 2-km resolution, and are aggregated at one-minute intervals. Spatial extent information that is not readily available in the GLM L2+ data is recovered and used to create the gridded products.

The new gridded products are:

- Minimum Flash Area
- Flash Extent Density
- Total Optical Energy

This software package was developed at the University of Wisconsin - Madison, SSEC / CIMSS, under funding provided by the GOES-R Program and NOAA STAR.

The latest version of this software can be obtained from: <https://cimss.ssec.wisc.edu/csppgeo/>

Questions and comments can be directed to <csppgeo.issues@ssec.wisc.edu>.


## ATTRIBUTION

The software package is built on the open source glmtools software developed by Dr. Eric Bruning (Texas Tech University). Development of operational Gridded GLM products and related research is led by Dr. Scott Rudlosky (NOAA/NESDIS/STAR).

This release builds on two years of effort to refine the glmtools package in pre-operational demonstrations, and many of the contributors to that effort are coauthors on the paper that describes the GLM imagery creation approach in detail.

Bruning, E. C., Tillier, C. E., Edgington, S. F., Rudlosky, S. D., Zajic, J. K., Gravelle, C. M., Foster, M., Calhoun, K. M., Campbell, P. A., Stano, G. T., Schultz, C. J., and Meyer, T. C. (2019). Meteorological imagery for the Geostationary Lightning Mapper.  2019: Meteorological imagery for the Geostationary Lightning Mapper. J. Geophys. Res., 124 (24), 14 285–14 309, https://doi.org/10.1029/2019JD030874

The developers wish to thank Lee Byerle and Joe Zajic, NWS TOWR-S team, for their assistance with tile development and AWIPS compatibility.


## COPYRIGHT / LICENSE

Portions of the source code in this software package are copyrighted by the 
University of Wisconsin Regents. This package includes original software
developed by the University of Wisconsin (UW), as well as third-party software 
libraries. UW software is licensed under the GNU General Public License Version 3. 
Other binary executable files and third-party source code are copyrighted and 
licensed by their respective organizations, and are distributed consistent with 
their licensing terms. For more information, refer to LICENSE and LICENSE.md files 
distributed with the software package.


## DISCLAIMER

The University of Wisconsin-Madison Space Science and Engineering Center 
(SSEC) makes no warranty of any kind with regard to the CSPP Geo software or 
any accompanying documentation, including but not limited to the implied 
warranties of merchantability and fitness for a particular purpose. SSEC does
not indemnify any infringement of copyright, patent, or trademark through the
use or modification of this software.
    
There is no expressed or implied warranty made to anyone as to the suitability
of this software for any purpose. All risk of use is assumed by the user. 
Users agree not to hold SSEC, the University of Wisconsin-Madison, or any of
its employees or assigns liable for any consequences resulting from the use of
the CSPP Geo software.


## INSTALLATION

To install, extract the tarball and optionally add the bin directory to your PATH.

```
tar xf cspp-geo-gridded-glm-1.1.0.tar.xz
export PATH=$PATH:$PWD/cspp-geo-gridded-glm-1.1/bin
```

A test data tarball can be downloaded from the same location as the software. Reference output is included. Refer to the EXAMPLES section below to run the test case.​


## USAGE

**cspp-geo-gglm.sh**

The main processing script creates one minute grids from GLM L2+ LCFA input files, which can be obtained from the CSPP Geo GRB software or from NOAA CLASS. It is recommended that all 3 20-second input files from the same minute be specified, to ensure that the gridded product captures all lightning activity from that minute. Alternatively the script can be run in "realtime" mode where, provided a single input file, it will determine if an entire minute is available and if so begin gridding. 

For a list of options, run `cspp-geo-gglm.sh -h`.


## OUTPUT

The Gridded GLM product is written by the main processing script in the form of NetCDF4 files spanning a clock-aligned minute of input data. The file naming convention and file format are modeled after the GOES-R operational format, as documented in the GOES-R Product Definition and Users' Guide (PUG).

Example Gridded GLM product filename: `CG_GLM-L2-GLMF-M3_G16_s20192991759000_e20192991800000_c20210492345130.nc`

A set of tiles can optionally be created for each Gridded GLM file. The tiles are also NetCDF4 files and designed to be compatible with AWIPS. Tiles covering geographic areas without lightning activity are omitted. The time in the filename is the observation end time.

Example tile filename: `CSPP_OR_GLM-L2-GLMF-M3_G16_T15_20191026180000.nc`


## EXAMPLES

Create a single one-minute gridded product file by specifying three input 20-second GLM L2+ files

`cspp-geo-gglm.sh /data/GLM-L2/2019299/17/OR_GLM-L2-LCFA_G16_s20192991759*`

Create a single one-minute gridded product file by specifying only one of the three input 20-second GLM L2+ files ("realtime" mode)

`cspp-geo-gglm.sh -r /data/GLM-L2/2019299/17/OR_GLM-L2-LCFA_G16_s20192991759400_e20192991800000_c20192991800031.nc`

Create a gridded product file and tiles

`cspp-geo-gglm.sh -r -t /data/GLM-L2/2019299/17/OR_GLM-L2-LCFA_G16_s20192991759400_e20192991800000_c20192991800031.nc`


## CAVEATS

The following issues are known to affect this release

- The DQF (data quality flags) are always set to 0 in this version. Proper data quality information will be added in a future version
- Tile generation with CONUS and mesoscale gridding has not been fully tested


## REFERENCES

Documentation:

- [GOES-R Gridded GLM Quick Guides](https://vlab.noaa.gov/web/geostationary-lightning-mapper/training)
- [NOAA Virtual Lab GLM Community](https://vlab.noaa.gov/web/geostationary-lightning-mapper)
- [University of Maryland GLM Imagery](https://lightning.umd.edu/glm/)

Software:

- [glmtools software repository](https://github.com/deeplycloudy/glmtools)
